#[repr(C)]pub struct UtcOffset {
seconds: ri8<{ _ }, { _ }>,
minutes: ri8<{ _ }, { _ }>,
hours: ri8<-25, 25>,
}Expand description
An offset from UTC.
This struct can store values up to ±25:59:59. If you need support outside this range, please file an issue with your use case.
Fields
seconds: ri8<{ _ }, { _ }>minutes: ri8<{ _ }, { _ }>hours: ri8<-25, 25>Implementations
Sourceimpl UtcOffset
impl UtcOffset
Sourcepub(crate) const fn as_u32_for_equality(self) -> u32
pub(crate) const fn as_u32_for_equality(self) -> u32
Provide a representation of the UtcOffset as a i32. This value can be used for equality,
and hashing. This value is not suitable for ordering; use as_i32_for_comparison instead.
Sourceconst fn as_i32_for_comparison(self) -> i32
const fn as_i32_for_comparison(self) -> i32
Provide a representation of the UtcOffset as a i32. This value can be used for ordering.
While it is suitable for equality, as_u32_for_equality is preferred for performance
reasons.
Sourcepub const fn from_hms(
hours: i8,
minutes: i8,
seconds: i8,
) -> Result<Self, ComponentRange>
pub const fn from_hms( hours: i8, minutes: i8, seconds: i8, ) -> Result<Self, ComponentRange>
Create a UtcOffset representing an offset by the number of hours, minutes, and seconds
provided.
The sign of all three components should match. If they do not, all smaller components will have their signs flipped.
Sourcepub(crate) const fn from_hms_ranged_unchecked(
hours: ri8<-25, 25>,
minutes: ri8<{ _ }, { _ }>,
seconds: ri8<{ _ }, { _ }>,
) -> Self
pub(crate) const fn from_hms_ranged_unchecked( hours: ri8<-25, 25>, minutes: ri8<{ _ }, { _ }>, seconds: ri8<{ _ }, { _ }>, ) -> Self
Create a UtcOffset representing an offset of the hours, minutes, and seconds provided. All
three parameters must have the same sign.
While the signs of the parameters are required to match, this is not a safety invariant.
Sourcepub(crate) const fn from_hms_ranged(
hours: ri8<-25, 25>,
minutes: ri8<{ _ }, { _ }>,
seconds: ri8<{ _ }, { _ }>,
) -> Self
pub(crate) const fn from_hms_ranged( hours: ri8<-25, 25>, minutes: ri8<{ _ }, { _ }>, seconds: ri8<{ _ }, { _ }>, ) -> Self
Create a UtcOffset representing an offset by the number of hours, minutes, and seconds
provided.
The sign of all three components should match. If they do not, all smaller components will have their signs flipped.
Sourcepub const fn from_whole_seconds(seconds: i32) -> Result<Self, ComponentRange>
pub const fn from_whole_seconds(seconds: i32) -> Result<Self, ComponentRange>
Sourcepub(crate) const fn from_whole_seconds_ranged(
seconds: ri32<{ _ }, { _ }>,
) -> Self
pub(crate) const fn from_whole_seconds_ranged( seconds: ri32<{ _ }, { _ }>, ) -> Self
Create a UtcOffset representing an offset by the number of seconds provided.
assert_eq!(
UtcOffset::from_whole_seconds_ranged(RangedI32::new_static::<3_723>()).as_hms(),
(1, 2, 3)
);Sourcepub(crate) const fn as_hms_ranged(
self,
) -> (ri8<-25, 25>, ri8<{ _ }, { _ }>, ri8<{ _ }, { _ }>)
pub(crate) const fn as_hms_ranged( self, ) -> (ri8<-25, 25>, ri8<{ _ }, { _ }>, ri8<{ _ }, { _ }>)
Obtain the UTC offset as its hours, minutes, and seconds. The sign of all three components will always match. A positive value indicates an offset to the east; a negative to the west.
Sourcepub const fn whole_hours(self) -> i8
pub const fn whole_hours(self) -> i8
Sourcepub const fn whole_minutes(self) -> i16
pub const fn whole_minutes(self) -> i16
Sourcepub const fn minutes_past_hour(self) -> i8
pub const fn minutes_past_hour(self) -> i8
Sourcepub const fn whole_seconds(self) -> i32
pub const fn whole_seconds(self) -> i32
Sourcepub const fn seconds_past_minute(self) -> i8
pub const fn seconds_past_minute(self) -> i8
Sourcepub const fn is_positive(self) -> bool
pub const fn is_positive(self) -> bool
Sourcepub const fn is_negative(self) -> bool
pub const fn is_negative(self) -> bool
Sourcepub fn local_offset_at(
datetime: OffsetDateTime,
) -> Result<Self, IndeterminateOffset>
pub fn local_offset_at( datetime: OffsetDateTime, ) -> Result<Self, IndeterminateOffset>
Sourcepub fn current_local_offset() -> Result<Self, IndeterminateOffset>
pub fn current_local_offset() -> Result<Self, IndeterminateOffset>
Sourceimpl UtcOffset
impl UtcOffset
Sourcepub fn format_into(
self,
output: &mut (impl Write + ?Sized),
format: &(impl Formattable + ?Sized),
) -> Result<usize, Format>
pub fn format_into( self, output: &mut (impl Write + ?Sized), format: &(impl Formattable + ?Sized), ) -> Result<usize, Format>
Format the UtcOffset using the provided format description.
Sourcepub fn format(
self,
format: &(impl Formattable + ?Sized),
) -> Result<String, Format>
pub fn format( self, format: &(impl Formattable + ?Sized), ) -> Result<String, Format>
Format the UtcOffset using the provided format description.
Sourceimpl UtcOffset
impl UtcOffset
Sourceimpl UtcOffset
impl UtcOffset
Sourcepub(crate) const DISPLAY_BUFFER_SIZE: usize = 9
pub(crate) const DISPLAY_BUFFER_SIZE: usize = 9
The maximum number of bytes that the fmt_into_buffer method will write, which is also used
for the Display implementation.
Sourcepub(crate) const fn fmt_into_buffer(
self,
buf: &mut [MaybeUninit<u8>; 9],
) -> usize
pub(crate) const fn fmt_into_buffer( self, buf: &mut [MaybeUninit<u8>; 9], ) -> usize
Format the UtcOffset into the provided buffer, returning the number of bytes written.